@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-core
 version: 1.4.20.2
-id: yesod-core-1.4.20.2-014d072d2152bbd04ae4cfe76f84438d
-key: yesod_9x5ixKSPBnb3BT17wR5G3v
+id: yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
+key: yesod_7HpwgXt7i0O83nERXlBqd9
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -33,7 +33,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.20.2
-hs-libraries: HSyesod-core-1.4.20.2-9x5ixKSPBnb3BT17wR5G3v
+hs-libraries: HSyesod-core-1.4.20.2-7HpwgXt7i0O83nERXlBqd9
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     auto-update-0.1.4-5802161b0d99b2a30d57c95848e07a31
@@ -62,14 +62,14 @@ depends:
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
-    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
+    shakespeare-2.0.8.2-b321569ec5295e19a9b3f8b5ef85b2ad
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
@@ -81,7 +81,7 @@ depends:
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
     wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
     wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
-    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
+    warp-3.2.6-0273436dc44d76eb20f09024e8daa00c
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
 haddock-html: /usr/share/doc/haskell-yesod-core/html
